@@ -1,6 +1,6 @@
 import argparse
 
-from savgol import get_coefficients
+from SGCC.savgol import get_coefficients
 
 
 def get_arguments():
@@ -28,12 +28,17 @@ if __name__ == "__main__":
     # Get command line arguments
     args = get_arguments()
 
-    # Compute half of window_size (rounded down)
-    half_window = args.window_size // 2
+    print("Computing Savitsky-Golay filter coefficients with parameters:")
+    print(f"\t-Window size: {args.window_size}")
+    print(f"\t-Polynomial fit order: {args.order}")
+    print(f"\t-Offset from center point: {args.offset}")
+    print(f"\t-Estimation parameter: {args.smoothing} (0:smoothing, 1:first derivative, ...)")
+    print()
+    print("Filter coefficients:")
 
     # Print resulting coefficients to terminal
     print("[", end="")
-    for i, coeff in enumerate(get_coefficients(args.smoothing, args.order, args.offset, half_window)):
+    for i, coeff in enumerate(get_coefficients(args.smoothing, args.order, args.window_size, args.offset)):
         end = ", " if i < args.window_size - 1 else ""
         print(f"{coeff:0.5f}", end=end)
     print("]")
